BinaryConversion<T> constructor

BinaryConversion<T>(
  1. void _onValue(
    1. T
    )
)

Create a BinaryConversion with the specified callback.

The callback will be invoked whenever this conversion produces a value as a result of a call to add or addAll.

Implementation

BinaryConversion(this._onValue);