BinarySerializable class
An annotation to indicate binary_serializable_generator should generate a
BinaryType for a class.
When applied to a class, binary_serializable_generator generates a
BinaryType that calls the class's default (unnamed) constructor.
When applies to a constructor, binary_serializable_generator generates a
BinaryType for the constructor's enclosing class that calls the specified
constructor.
- Annotations
-
- @Target.new({TargetKind.classType, TargetKind.constructor})
Constructors
- BinarySerializable()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited