BufferConversion class

A BinaryConversion that produces a buffer containing a set amount of bytes.

Inheritance

Constructors

BufferConversion(int length, void onValue(Uint8List))
Create a new BufferConversion.

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
The number of bytes to read into the buffer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Uint8List data) int
Add data to this conversion.
override
addAll(Uint8List data) → void
Adds all of data to this conversion.
inherited
flush() → void
Ensure this conversion is not currently deserializing a Dart object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onValue(Uint8List value) → void
Called when the conversion produces a value in response to an add or addAll call.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited