BoolType class
A BinaryType for bools.
false is encoded as a uint8 with a value of 0. true is encoded as any
other uint8 value (though 1 is commonly used).
Constructors
- BoolType()
-
A BinaryType for bools.
const
Properties
-
decoder
→ Converter<
List< int> , bool> -
Returns the decoder of
this, converting fromTtoS.no setterinherited -
encoder
→ Converter<
bool, Uint8List> -
Returns the encoder from
StoT.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
List< int> , bool> -
Inverts
this.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
List< int> encoded) → bool -
Decodes
encodeddata.inherited -
decodeStream(
Stream< List< stream) → Future<int> >bool> -
Decode a single value from
stream.inherited -
encode(
bool input) → Uint8List -
Encodes
input.inherited -
encodeInto(
bool input, BytesBuilder builder) → void -
Encode
inputintobuilder.override -
fuse<
R> (Codec< List< other) → Codec<int> , R>bool, R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startConversion(
void onValue(bool)) → BinaryConversion< bool> -
Start a new BinaryConversion that converts binary data to this type.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited