BufferConversion class
A BinaryConversion that produces a buffer containing a set amount of bytes.
- Inheritance
-
- Object
- BinaryConversion<
Uint8List> - BufferConversion
Constructors
- BufferConversion(int length, void onValue(Uint8List))
- Create a new BufferConversion.
Properties
Methods
-
add(
Uint8List data) → int -
Add
datato this conversion.override -
addAll(
Uint8List data) → void -
Adds all of
datato this conversion.inherited -
flush(
) → void -
Ensure this conversion is not currently deserializing a Dart object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onValue(
Uint8List value) → void -
Called when the conversion produces a value in response to an add or
addAll call.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited