BufferType class
A BinaryType for reading buffers of a given length.
This type does not validate the length of buffers it encodes.
Constructors
- BufferType(int length)
-
Create a new BufferType for a specified
length.const
Properties
-
decoder
→ Converter<
List< int> , Uint8List> -
Returns the decoder of
this, converting fromTtoS.no setterinherited -
encoder
→ Converter<
Uint8List, Uint8List> -
Returns the encoder from
StoT.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
List< int> , Uint8List> -
Inverts
this.no setterinherited - length → int
-
The length of the buffer to read.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
List< int> encoded) → Uint8List -
Decodes
encodeddata.inherited -
decodeStream(
Stream< List< stream) → Future<int> >Uint8List> -
Decode a single value from
stream.inherited -
encode(
Uint8List input) → Uint8List -
Encodes
input.inherited -
encodeInto(
Uint8List input, BytesBuilder builder) → void -
Encode
inputintobuilder.override -
fuse<
R> (Codec< List< other) → Codec<int> , R>Uint8List, R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startConversion(
void onValue(Uint8List p1)) → BinaryConversion< Uint8List> -
Start a new BinaryConversion that converts binary data to this type.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited