CompositeBinaryConversion<T> class
abstract
A BinaryConversion that composes multiple BinaryConversions to form a composite object.
CompositeBinaryConversion may be used as a superclass for any class implementing a BinaryConversion as sequentially passing data through several other BinaryConversions.
- Inheritance
-
- Object
- BinaryConversion<
T> - CompositeBinaryConversion
Constructors
- CompositeBinaryConversion(void onValue(T))
- Create a new CompositeBinaryConversion with the given callback.
Properties
- currentConversion ← BinaryConversion
-
Sets the current conversion in response to another conversion producing a
value.
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
Uint8List data) → int -
Add
datato this conversion.override -
addAll(
Uint8List data) → void -
Adds all of
datato this conversion.inherited -
flush(
) → void -
Ensure this conversion is not currently deserializing a Dart object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onValue(
T value) → void -
Called when the conversion produces a value in response to an add or
addAll call.
override
-
startConversion(
) → BinaryConversion - Called when the conversion of a new object is started.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited