FloatType class
A BinaryType for doubles.
This BinaryType is a generic implementation for all double encodings. See the constants declared in this library for instances of this type for specific encodings.
Constructors
Properties
-
decoder
→ Converter<
List< int> , double> -
Returns the decoder of
this, converting fromTtoS.no setterinherited -
encoder
→ Converter<
double, Uint8List> -
Returns the encoder from
StoT.no setterinherited - endian → Endian
-
The endianness of this type's encoding.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
List< int> , double> -
Inverts
this.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
The width of this type's encoding, in bytes.
final
Methods
-
decode(
List< int> encoded) → double -
Decodes
encodeddata.inherited -
decodeStream(
Stream< List< stream) → Future<int> >double> -
Decode a single value from
stream.inherited -
encode(
double input) → Uint8List -
Encodes
input.override -
encodeInto(
double input, BytesBuilder builder) → void -
Encode
inputintobuilder.override -
fuse<
R> (Codec< List< other) → Codec<int> , R>double, R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startConversion(
void onValue(double)) → BinaryConversion< double> -
Start a new BinaryConversion that converts binary data to this type.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited