Generic class
A marker value to be used in place of a generic BinaryType.
This class can be used in type annotations for
binary_serializable_generator in order to indicate the binary type depends
on a generic and should be a parameter to the generated BinaryType.
The single parameter specifies which type parameter of the class to target.
This class must not be used at runtime.
- Inheritance
-
- Object
- Codec<
Never, List< int> > - BinaryType<
Never> - Generic
- Annotations
-
- @Target.new({TargetKind.getter, TargetKind.field})
Constructors
- Generic(String name)
-
A marker value to be used in place of a generic BinaryType.
const
Properties
-
decoder
→ Converter<
List< int> , Never> -
Returns the decoder of
this, converting fromTtoS.no setterinherited -
encoder
→ Converter<
Never, Uint8List> -
Returns the encoder from
StoT.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
List< int> , Never> -
Inverts
this.no setterinherited - name → String
-
The name of the type parameter this generic will be substituted for.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
List< int> encoded) → Never -
Decodes
encodeddata.inherited -
decodeStream(
Stream< List< stream) → Future<int> >Never> -
Decode a single value from
stream.inherited -
encode(
Never input) → Uint8List -
Encodes
input.inherited -
encodeInto(
Never input, BytesBuilder builder) → Uint8List -
Encode
inputintobuilder.override -
fuse<
R> (Codec< List< other) → Codec<int> , R>Never, R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startConversion(
void onValue(Never p1)) → BinaryConversion< Never> -
Start a new BinaryConversion that converts binary data to this type.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited